PruningFilter

Trait PruningFilter 

pub trait PruningFilter: Send + Sync {
    // Required method
    fn should_retain(&self, justifications: &Justifications) -> bool;
}
Filter to determine if a block should be excluded from pruning.

Note: This filter only affects block body (and future header) pruning. It does not affect state pruning, which is configured separately.

Required Methods

fn should_retain(&self, justifications: &Justifications) -> bool

Check if a block with the given justifications should be preserved.

Returns true to preserve the block, false to allow pruning.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<F> PruningFilter for F
where F: Fn(&Justifications) -> bool + Send + Sync,